CallTimer class

Constructors

CallTimer({Duration elapsed = Duration.zero, OnTimerTick? onTimerTick})

Properties

elapsed Duration
Get the elapsed time.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state StopwatchState
Get the current state of the stopwatch.
no setter

Methods

describe() String
Describe the elapsed time in the format HH:MM:SS.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pause() → void
Pause the stopwatch if it is running.
resume() → void
Resume the stopwatch if it is paused.
setOnTick(OnTimerTick? value) → void
start() → void
Start the stopwatch if it is stopped.
stop() → void
Stop the stopwatch and reset the elapsed time.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

secondDuration → const Duration