CallkitConfig class

TODO: we want customized:

  • custom ringing sound
  • vibration
  • custom icon for active/incoming call(s) and queued, held, etc. calls

Constructors

CallkitConfig({required String appName, required String incomingRingtone, required CallConfig callConfig, required NotificationConfig notificationConfig, required Set<CKCapability> capabilities, required Set<CKCallAttributes> attributes})

Properties

appName String
final
attributes Set<CKCallAttributes>
final
callConfig CallConfig
final
capabilities Set<CKCapability>
final
hashCode int
The hash code for this object.
no setterinherited
incomingRingtone String
final
notificationConfig NotificationConfig
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited