NotificationManager class abstract

Implementers

Constructors

NotificationManager()

Properties

actionStream Stream<CKCallResult>
Obtain stream for notification click/actions i.e. CKNotificationAction button clicks. On tapping a notification, this is considered an action. These notifications are reposted immediately to ensure transparency of the call state. A notification can be reposted automatically with the repostOnClick property. TODO: Implement repostOnClick
no setter
dismissStream Stream<CKCallResult>
Obtain stream for notification dismiss events. Dismiss events include clicking the close button on the notification.
no setter
hashCode int
The hash code for this object.
no setterinherited
notificationChangeStream Stream<CKNotification>
Obtain stream describing changes to notifications
no setter
notificationStream Stream<Iterable<CKNotification>>
Obtain stream of all notifications currently visible
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tapStream Stream<CKCallResult>
Notification tap interaction stream. Taps include clicking anywhere on the notification except the close, or CKNotificationAction buttons (except empty actions). Action buttons with an empty action will be treated as a tap.
no setter

Methods

add(CKNotification notification, {Map<String, bool>? flags}) Future<void>
Add a notification to the notification manager, overwriting existing an notification with the same CKNotification.uuid
dismiss({required String uuid}) Future<void>
Dismiss a notification by uuid
dispose() Future<void>
Dispose of the notification manager, releasing resources & streams
getAllNotifications() Iterable<CKNotification>
Get all notifications currently visible.
getNotification(String uuid) CKNotification?
Get a notification by uuid
hasPermissions() Future<bool>
Check if the notification permissions are granted
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requestPermissions() Future<bool>
Requests notification permissions from web browser
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

CK_EXTRA_PERSIST → const String
tag → const String