CKActionSource enum
Describes the notification action source. Distinguishes between actions triggered by the user by Notification Action click events and actions triggered by the API.
Values
- notification → const CKActionSource
-
from notification or user input
- api → const CKActionSource
-
from API or internal
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
CKActionSource> - A constant List of the values in this enum, in order of their declaration.