CKAssetSound class
Constructors
- CKAssetSound(String asset, {bool looping = false, bool enabled = true, Duration delay = const Duration(seconds: 0), CKSoundType type = CKSoundType.asset})
-
const
Properties
- asset → String
-
final
- delay → Duration
-
finalinherited
- enabled → bool
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- looping → bool
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → CKSoundType
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited